define([
  'expect',
  'jquery',
  'pat-registry',
  'mockup-patterns-highlightjs'
], function(expect, $, registry, highlightjs) {
  'use strict';

  // window.mocha.setup('bdd');
  // $.fx.off = true;

  // describe('highlightjs', function () {

  //   afterEach(function() {
  //     $('body').empty();
  //   });

  //   it('Just works.', function() {

  //     var $doc = $('<div class="pat-highlightjs"></div>').appendTo('body');
  //     registry.scan($doc);

  //     setTimeout(function () {
  //       // wait for two seconds, until all is settled.
  //       // TODO: use event listener instead.
  //       var $el = $('.pat-highlightjs');
  //       expect($el.text()).to.be.equal("Super Duper!");
  //     }, 2000);

  //   });

  // });
});
